extern crate sfml;

use sfml::graphics::{CircleShape, Color, ConvexShape, Font, RenderTarget, RenderWindow, Sprite,
                     Text, Texture, Transformable};
use sfml::window::{Key, VideoMode, Event, style};
use sfml::system::Vector2f;

fn main() {
    let mut window = RenderWindow::new(VideoMode::new(800, 600, 32),
                                       "Borrowed resources",
                                       style::CLOSE,
                                       &Default::default())
            .unwrap();
    window.set_vertical_sync_enabled(true);

    // Create a new texture. (Hey Frank!)
    let frank = Texture::from_file("resources/frank.jpeg").unwrap();

    // Create a font.
    let font = Font::from_file("resources/sansation.ttf").unwrap();

    // Create a circle with the Texture.
    let mut circle = CircleShape::with_texture(&frank);
    circle.set_radius(70.0);
    circle.set_position2f(100.0, 100.0);

    // Create a Sprite.
    let mut sprite = Sprite::new();
    // Have it use the same texture as the circle.
    sprite.set_texture(&frank, true);
    sprite.set_position2f(400.0, 300.0);
    sprite.set_scale2f(0.5, 0.5);

    // Create a ConvexShape using the same texture.
    let mut convex_shape = ConvexShape::with_texture(&frank, 6);
    convex_shape.set_point(0,
                           &Vector2f {
                                x: 400.0,
                                y: 100.0,
                            });
    convex_shape.set_point(1,
                           &Vector2f {
                                x: 500.0,
                                y: 70.0,
                            });
    convex_shape.set_point(2,
                           &Vector2f {
                                x: 450.0,
                                y: 100.0,
                            });
    convex_shape.set_point(3,
                           &Vector2f {
                                x: 580.0,
                                y: 150.0,
                            });
    convex_shape.set_point(4,
                           &Vector2f {
                                x: 420.0,
                                y: 230.0,
                            });
    convex_shape.set_point(5,
                           &Vector2f {
                                x: 420.0,
                                y: 120.0,
                            });

    // Create an initialized text using the font.
    let title = Text::new_init("Borrowed resources example!", &font, 50);

    // Create a second text using the same font.
    // This time, we create and initialize it separately.
    let mut second_text = Text::new();
    second_text.set_string("This text shares the same font with the title!");
    second_text.set_font(&font);
    second_text.set_fill_color(&Color::green());
    second_text.set_position2f(10.0, 350.0);
    second_text.set_character_size(20);

    // Create a third text using the same font.
    let mut third_text = Text::new_init("This one too!", &font, 20);
    third_text.set_position2f(300.0, 100.0);
    third_text.set_fill_color(&Color::red());

    loop {
        for event in window.events() {
            match event {
                Event::Closed |
                Event::KeyPressed { code: Key::Escape, .. } => return,
                _ => {}
            }
        }

        window.clear(&Color::black());
        window.draw(&circle);
        window.draw(&sprite);
        window.draw(&convex_shape);
        window.draw(&title);
        window.draw(&second_text);
        window.draw(&third_text);
        window.display();
    }
}
